==> qwit-0.8-src.tar.bz2: qwit-0.8-src/translations/qwit_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ru">
<context>
    <name>LogsDialog</name>
    <message>
        <location filename="../src/LogsDialog.ui" line="13"/>
        <source>Logs</source>
        <translation>Логи</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/MainWindow.cpp" line="218"/>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Показать / Скрыть</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="220"/>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="741"/>
        <source>Qwit updates</source>
        <translation>Обновления Qwit</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="13"/>
        <source>Qwit</source>
        <translation>Qwit</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="39"/>
        <source>What are you doing?</source>
        <translation>Что вы сейчас делаете?</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="205"/>
        <source>Left characters count - please, do not exceed this number</source>
        <translation>Количество оставшихся символов - пожалуйста, не превышайте это число</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="214"/>
        <source>140</source>
        <translation>140</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="236"/>
        <source>Home</source>
        <translation>Главная</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="239"/>
        <source>Your and your friends&apos; timeline</source>
        <translation>Сообщения от вас и ваших друзей</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="244"/>
        <source>Public</source>
        <translation>Все</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="247"/>
        <source>Public timeline</source>
        <translation>Сообщения ото всех</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="252"/>
        <source>Replies</source>
        <translation>Ответы</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="255"/>
        <source>Replies to you</source>
        <translation>Ответы вам</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="260"/>
        <source>Custom</source>
        <translation>Отдельно</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="263"/>
        <source>Custom user timeline</source>
        <translation>Сообщения отдельного пользователя</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="273"/>
        <source>Username:</source>
        <translation>Имя пользователя:</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="369"/>
        <source>Refresh</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="379"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="398"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="441"/>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="288"/>
        <source>Inbox</source>
        <translation>Входящие</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="291"/>
        <source>Direct messages inbox</source>
        <translation>Входящие сообщения</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="296"/>
        <source>Outbox</source>
        <translation>Исходящие</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="299"/>
        <source>Direct messages outbox</source>
        <translation>Исходящие сообщения</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="304"/>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="317"/>
        <source>Search:</source>
        <translation>Искать:</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="307"/>
        <source>Search for messages</source>
        <translation>Поиск сообщений</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../src/OptionsDialog.ui" line="13"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="25"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="66"/>
        <source>Update interval:</source>
        <translation>Интервал обновлений:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="79"/>
        <source>Number of messages per page:</source>
        <translation>Количество сообщений на странице:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="184"/>
        <source>Connection</source>
        <translation>Соединение</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="192"/>
        <source>use proxy</source>
        <translation>использовать прокси</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="199"/>
        <source>Proxy address:</source>
        <translation>Адрес прокси-сервера:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="212"/>
        <source>Proxy port:</source>
        <translation>Порт прокси-сервера:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="225"/>
        <source>Proxy username:</source>
        <translation>Имя пользователя:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="238"/>
        <source>Proxy password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="255"/>
        <source>save proxy password</source>
        <translation>сохранять пароль для прокси</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="278"/>
        <source>Authentication</source>
        <translation>Аутентификация</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="286"/>
        <source>Username or email:</source>
        <translation>Имя пользователя или email:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="299"/>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="316"/>
        <source>save password</source>
        <translation>сохранять пароль</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="361"/>
        <source>Save options</source>
        <translation>Сохранить настройки</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="368"/>
        <source>Reset options</source>
        <translation>Сбросить настройки</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="46"/>
        <source>Service base URL:</source>
        <translation>Базовый адрес сервиса:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="56"/>
        <source>Service API URL:</source>
        <translation>Адрес API сервиса:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="148"/>
        <source>Notify about updates</source>
        <translation>Информировать об обновлениях</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="36"/>
        <source>Greeting message:</source>
        <translation>Приветствие:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="92"/>
        <source>Number of messages per tray:</source>
        <translation>Количество сообщений в уведомлении:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="138"/>
        <source>Username under avatar</source>
        <translation>Имя пользователя под аватар</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="115"/>
        <source>Display retweet tag after text instead of in front</source>
        <translation>Отображать тег ретвита после текста а не перед ним</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="105"/>
        <source>Retweeting tag:</source>
        <translation>Тэг ретвита:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="158"/>
        <source>Place controls vertically</source>
        <translation>Расположить кнопки вертикально</translation>
    </message>
</context>
<context>
    <name>Twitter</name>
    <message>
        <location filename="../src/Twitter.cpp" line="140"/>
        <source>Error sending status: %1</source>
        <translation>Ошибка при отправлении статуса: %1</translation>
    </message>
    <message>
        <location filename="../src/Twitter.cpp" line="143"/>
        <source>Status sent: %1</source>
        <translation>Статус отправлен: %1</translation>
    </message>
    <message>
        <location filename="../src/Twitter.cpp" line="149"/>
        <source>Error while updating timeline: %1</source>
        <translation>Ошибка обновления: %1</translation>
    </message>
    <message>
        <location filename="../src/Twitter.cpp" line="153"/>
        <source>Timeline updated: %1</source>
        <translation>Сообщения обновлены: %1</translation>
    </message>
    <message>
        <location filename="../src/Twitter.cpp" line="134"/>
        <source>Updating timeline: %1</source>
        <translation>Обновление сообщения: %1</translation>
    </message>
    <message>
        <location filename="../src/Twitter.cpp" line="95"/>
        <source>Sending status: %1</source>
        <translation>Отправка статуса: %1</translation>
    </message>
</context>
<context>
    <name>TwitterWidget</name>
    <message numerus="yes">
        <location filename="../src/TwitterWidget.cpp" line="267"/>
        <source>about %n second(s) ago</source>
        <translation>
            <numerusform>примерно %n секунду назад</numerusform>
            <numerusform>примерно %n секунды назад</numerusform>
            <numerusform>примерно %n секунд назад</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/TwitterWidget.cpp" line="269"/>
        <source>about %n minute(s) ago</source>
        <translation>
            <numerusform>примерно %n минуту назад</numerusform>
            <numerusform>примерно %n минуты назад</numerusform>
            <numerusform>примерно %n минут назад</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/TwitterWidget.cpp" line="271"/>
        <source>about %n hour(s) ago</source>
        <translation>
            <numerusform>примерно %n час назад</numerusform>
            <numerusform>примерно %n часа назад</numerusform>
            <numerusform>примерно %n часов назад</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/TwitterWidget.cpp" line="273"/>
        <source>about %n day(s) ago</source>
        <translation>
            <numerusform>примерно %n день назад</numerusform>
            <numerusform>примерно %n дня назад</numerusform>
            <numerusform>примерно %n дней назад</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/TwitterWidget.cpp" line="266"/>
        <source>Just now</source>
        <translation>Только что</translation>
    </message>
</context>
<context>
    <name>UserpicsDownloader</name>
    <message>
        <location filename="../src/UserpicsDownloader.cpp" line="43"/>
        <source>Downloading: %1</source>
        <translation>Загрузка: %1</translation>
    </message>
    <message>
        <location filename="../src/UserpicsDownloader.cpp" line="57"/>
        <source>Error while downloading userpic: %1</source>
        <translation>Ошибка при загрузке изображения пользователя: %1</translation>
    </message>
    <message>
        <location filename="../src/UserpicsDownloader.cpp" line="62"/>
        <source>Downloaded: %1</source>
        <translation>Загружено: %1</translation>
    </message>
</context>
</TS>

==> qwit-0.9-src.tar.bz2: qwit-0.9-src/translations/qwit_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ru">
<context>
    <name>LogsDialog</name>
    <message>
        <location filename="../src/LogsDialog.ui" line="13"/>
        <source>Logs</source>
        <translation>Логи</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/MainWindow.cpp" line="218"/>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Показать / Скрыть</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="220"/>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="741"/>
        <source>Qwit updates</source>
        <translation>Обновления Qwit</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="13"/>
        <source>Qwit</source>
        <translation>Qwit</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="39"/>
        <source>What are you doing?</source>
        <translation>Что вы сейчас делаете?</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="205"/>
        <source>Left characters count - please, do not exceed this number</source>
        <translation>Количество оставшихся символов - пожалуйста, не превышайте это число</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="214"/>
        <source>140</source>
        <translation>140</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="236"/>
        <source>Home</source>
        <translation>Главная</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="239"/>
        <source>Your and your friends&apos; timeline</source>
        <translation>Сообщения от вас и ваших друзей</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="244"/>
        <source>Public</source>
        <translation>Все</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="247"/>
        <source>Public timeline</source>
        <translation>Сообщения ото всех</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="252"/>
        <source>Replies</source>
        <translation>Ответы</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="255"/>
        <source>Replies to you</source>
        <translation>Ответы вам</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="260"/>
        <source>Custom</source>
        <translation>Отдельно</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="263"/>
        <source>Custom user timeline</source>
        <translation>Сообщения отдельного пользователя</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="273"/>
        <source>Username:</source>
        <translation>Имя пользователя:</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="369"/>
        <source>Refresh</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="379"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="398"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="441"/>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="288"/>
        <source>Inbox</source>
        <translation>Входящие</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="291"/>
        <source>Direct messages inbox</source>
        <translation>Входящие сообщения</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="296"/>
        <source>Outbox</source>
        <translation>Исходящие</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="299"/>
        <source>Direct messages outbox</source>
        <translation>Исходящие сообщения</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="304"/>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="317"/>
        <source>Search:</source>
        <translation>Искать:</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.ui" line="307"/>
        <source>Search for messages</source>
        <translation>Поиск сообщений</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../src/OptionsDialog.ui" line="13"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="25"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="66"/>
        <source>Update interval:</source>
        <translation>Интервал обновлений:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="79"/>
        <source>Number of messages per page:</source>
        <translation>Количество сообщений на странице:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="184"/>
        <source>Connection</source>
        <translation>Соединение</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="192"/>
        <source>use proxy</source>
        <translation>использовать прокси</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="199"/>
        <source>Proxy address:</source>
        <translation>Адрес прокси-сервера:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="212"/>
        <source>Proxy port:</source>
        <translation>Порт прокси-сервера:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="225"/>
        <source>Proxy username:</source>
        <translation>Имя пользователя:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="238"/>
        <source>Proxy password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="255"/>
        <source>save proxy password</source>
        <translation>сохранять пароль для прокси</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="278"/>
        <source>Authentication</source>
        <translation>Аутентификация</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="286"/>
        <source>Username or email:</source>
        <translation>Имя пользователя или email:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="299"/>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="316"/>
        <source>save password</source>
        <translation>сохранять пароль</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="361"/>
        <source>Save options</source>
        <translation>Сохранить настройки</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="368"/>
        <source>Reset options</source>
        <translation>Сбросить настройки</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="46"/>
        <source>Service base URL:</source>
        <translation>Базовый адрес сервиса:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="56"/>
        <source>Service API URL:</source>
        <translation>Адрес API сервиса:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="148"/>
        <source>Notify about updates</source>
        <translation>Информировать об обновлениях</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="36"/>
        <source>Greeting message:</source>
        <translation>Приветствие:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="92"/>
        <source>Number of messages per tray:</source>
        <translation>Количество сообщений в уведомлении:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="138"/>
        <source>Username under avatar</source>
        <translation>Имя пользователя под аватар</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="115"/>
        <source>Display retweet tag after text instead of in front</source>
        <translation>Отображать тег ретвита после текста а не перед ним</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="105"/>
        <source>Retweeting tag:</source>
        <translation>Тэг ретвита:</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="158"/>
        <source>Place controls vertically</source>
        <translation>Расположить кнопки вертикально</translation>
    </message>
    <message>
        <location filename="../src/OptionsDialog.ui" line="168"/>
        <source>Place tabs vertically</source>
        <translation>Расположить вкладки вертикально</translation>
    </message>
</context>
<context>
    <name>Twitter</name>
    <message>
        <location filename="../src/Twitter.cpp" line="140"/>
        <source>Error sending status: %1</source>
        <translation>Ошибка при отправлении статуса: %1</translation>
    </message>
    <message>
        <location filename="../src/Twitter.cpp" line="143"/>
        <source>Status sent: %1</source>
        <translation>Статус отправлен: %1</translation>
    </message>
    <message>
        <location filename="../src/Twitter.cpp" line="149"/>
        <source>Error while updating timeline: %1</source>
        <translation>Ошибка обновления: %1</translation>
    </message>
    <message>
        <location filename="../src/Twitter.cpp" line="153"/>
        <source>Timeline updated: %1</source>
        <translation>Сообщения обновлены: %1</translation>
    </message>
    <message>
        <location filename="../src/Twitter.cpp" line="134"/>
        <source>Updating timeline: %1</source>
        <translation>Обновление сообщения: %1</translation>
    </message>
    <message>
        <location filename="../src/Twitter.cpp" line="95"/>
        <source>Sending status: %1</source>
        <translation>Отправка статуса: %1</translation>
    </message>
</context>
<context>
    <name>TwitterWidget</name>
    <message numerus="yes">
        <location filename="../src/TwitterWidget.cpp" line="267"/>
        <source>about %n second(s) ago</source>
        <translation>
            <numerusform>около %n секунды назад</numerusform>
            <numerusform>около %n секунд назад</numerusform>
            <numerusform>около %n секунд назад</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/TwitterWidget.cpp" line="269"/>
        <source>about %n minute(s) ago</source>
        <translation>
            <numerusform>около %n минуты назад</numerusform>
            <numerusform>около %n минут назад</numerusform>
            <numerusform>около %n минут назад</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/TwitterWidget.cpp" line="271"/>
        <source>about %n hour(s) ago</source>
        <translation>
            <numerusform>около %n часа назад</numerusform>
            <numerusform>около %n часов назад</numerusform>
            <numerusform>около %n часов назад</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/TwitterWidget.cpp" line="273"/>
        <source>about %n day(s) ago</source>
        <translation>
            <numerusform>около %n дня назад</numerusform>
            <numerusform>около %n дней назад</numerusform>
            <numerusform>около %n дней назад</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/TwitterWidget.cpp" line="266"/>
        <source>Just now</source>
        <translation>Только что</translation>
    </message>
</context>
<context>
    <name>UserpicsDownloader</name>
    <message>
        <location filename="../src/UserpicsDownloader.cpp" line="43"/>
        <source>Downloading: %1</source>
        <translation>Загрузка: %1</translation>
    </message>
    <message>
        <location filename="../src/UserpicsDownloader.cpp" line="57"/>
        <source>Error while downloading userpic: %1</source>
        <translation>Ошибка при загрузке изображения пользователя: %1</translation>
    </message>
    <message>
        <location filename="../src/UserpicsDownloader.cpp" line="62"/>
        <source>Downloaded: %1</source>
        <translation>Загружено: %1</translation>
    </message>
</context>
</TS>
